Full featured example

### Translation

This page enables you to translate TinyMCE by using XML files.

Steps to translate:

1. Download one of the language XML files from the TinyMCE site.
2. Place it in /jscripts/tiny_mce/langs directory, for example /jscripts/tiny_mce/langs/sv.xml.
3. Change the language init option in this file to match the XML file code. For example: sv
4. TinyMCE will now use the XML file instead of the .js versions.
5. Modify the XML file until everything is translated
6. Modify the author information, this is optional.
7. Upload the XML file to the TinyMCE site to share it with others.
8. You can now download the .js versions of the language pack from the TinyMCE site.

<p> This is some example text that you can edit inside the <strong>TinyMCE editor</strong>. </p> <p> Nam nisi elit, cursus in rhoncus sit amet, pulvinar laoreet leo. Nam sed lectus quam, ut sagittis tellus. Quisque dignissim mauris a augue rutrum tempor. Donec vitae purus nec massa vestibulum ornare sit amet id tellus. Nunc quam mauris, fermentum nec lacinia eget, sollicitudin nec ante. Aliquam molestie volutpat dapibus. Nunc interdum viverra sodales. Morbi laoreet pulvinar gravida. Quisque ut turpis sagittis nunc accumsan vehicula. Duis elementum congue ultrices. Cras faucibus feugiat arcu quis lacinia. In hac habitasse platea dictumst. Pellentesque fermentum magna sit amet tellus varius ullamcorper. Vestibulum at urna augue, eget varius neque. Fusce facilisis venenatis dapibus. Integer non sem at arcu euismod tempor nec sed nisl. Morbi ultricies, mauris ut ultricies adipiscing, felis odio condimentum massa, et luctus est nunc nec eros. </p>